buildItem property
The required parameter that specifies the widget builder for the list item.
Implementation
final ItemBuilder<T> buildItem;
The required parameter that specifies the widget builder for the list item.
final ItemBuilder<T> buildItem;